@@ -44,6 +44,14 @@ class TestBranch < Test::Unit::TestCase
     end
   end
   
+  def test_true_branch_contains?
+    assert(@git.branch('git_grep').contains?('master'))
+  end
+
+  def test_false_branch_contains?
+    assert(!@git.branch('master').contains?('git_grep'))
+  end
+
   def test_branch_commit
     assert_equal(270, @git.branches[:test_branches].gcommit.size)
   end
@@ -54,6 +62,7 @@ class TestBranch < Test::Unit::TestCase
       Dir.chdir('branch_test') do
         assert(!g.branch('new_branch').current)
         g.branch('other_branch').create
+        assert(!g.branch('other_branch').current)
         g.branch('new_branch').checkout
         assert(g.branch('new_branch').current)
 
