@@ -46,6 +46,21 @@ class TestRemotes < Test::Unit::TestCase
     end
   end
   
+  def test_set_remote_url
+    in_temp_dir do |path|
+      local = Git.clone(@wbare, 'local')
+      remote1 = Git.clone(@wbare, 'remote1')
+      remote2 = Git.clone(@wbare, 'remote2')
+
+      local.add_remote('testremote', remote1)
+      local.set_remote_url('testremote', remote2)
+
+      assert(local.remotes.map{|b| b.name}.include?('testremote'))
+      assert(local.remote('testremote').url != remote1.repo.path)
+      assert(local.remote('testremote').url == remote2.repo.path)
+    end
+  end
+
   def test_remote_fun
     in_temp_dir do |path|
       loc = Git.clone(@wbare, 'local')
@@ -107,6 +122,34 @@ class TestRemotes < Test::Unit::TestCase
       assert(loc.tags.map(&:name).include?('test-tag-in-deleted-branch'))
     end
   end
+
+  def test_fetch_ref_adds_ref_option
+    in_temp_dir do |path|
+      loc = Git.clone(@wbare, 'local')
+      rem = Git.clone(@wbare, 'remote', :config => 'receive.denyCurrentBranch=ignore')
+      loc.add_remote('testrem', rem)
+      
+      loc.chdir do
+        new_file('test-file1', 'gonnaCommitYou')
+        loc.add
+        loc.commit('master commit 1')
+        first_commit_sha = loc.log.first.sha
+        
+        new_file('test-file2', 'gonnaCommitYouToo')
+        loc.add
+        loc.commit('master commit 2')
+        second_commit_sha = loc.log.first.sha
+
+        # Make sure fetch message only has the first commit when we fetch the first commit
+        assert(loc.fetch('origin', {:ref => first_commit_sha}).include?(first_commit_sha))
+        assert(!loc.fetch('origin', {:ref => first_commit_sha}).include?(second_commit_sha))
+
+        # Make sure fetch message only has the second commit when we fetch the second commit
+        assert(loc.fetch('origin', {:ref => second_commit_sha}).include?(second_commit_sha))
+        assert(!loc.fetch('origin', {:ref => second_commit_sha}).include?(first_commit_sha))        
+      end      
+    end
+  end
   
   def test_push
     in_temp_dir do |path|
